==> refcodes-forwardsecrecy-1.2.5-sources.jar: org/refcodes/forwardsecrecy/UnexpectedForwardSecrecyRuntimeException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany and licensed
// under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/LICENSE-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.forwardsecrecy;

/**
 * This exception is the base runtime exception for the directory artifact.
 */
public class UnexpectedForwardSecrecyRuntimeException extends ForwardSecrecyRuntimeException {

	private static final long serialVersionUID = 1L;

	/**
	 * Instantiates a new unexpected forward secrecy runtime exception.
	 *
	 * @param aMessage the message
	 * @param aErrorCode the error code
	 */
	public UnexpectedForwardSecrecyRuntimeException( String aMessage, String aErrorCode ) {
		super( aMessage, aErrorCode );
	}

	/**
	 * Instantiates a new unexpected forward secrecy runtime exception.
	 *
	 * @param aMessage the message
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public UnexpectedForwardSecrecyRuntimeException( String aMessage, Throwable aCause, String aErrorCode ) {
		super( aMessage, aCause, aErrorCode );
	}

	/**
	 * Instantiates a new unexpected forward secrecy runtime exception.
	 *
	 * @param message the message
	 * @param cause the cause
	 */
	public UnexpectedForwardSecrecyRuntimeException( String message, Throwable cause ) {
		super( message, cause );
	}

	/**
	 * Instantiates a new unexpected forward secrecy runtime exception.
	 *
	 * @param message the message
	 */
	public UnexpectedForwardSecrecyRuntimeException( String message ) {
		super( message );
	}

	/**
	 * Instantiates a new unexpected forward secrecy runtime exception.
	 *
	 * @param aCause the cause
	 * @param aErrorCode the error code
	 */
	public UnexpectedForwardSecrecyRuntimeException( Throwable aCause, String aErrorCode ) {
		super( aCause, aErrorCode );
	}

	/**
	 * Instantiates a new unexpected forward secrecy runtime exception.
	 *
	 * @param cause the cause
	 */
	public UnexpectedForwardSecrecyRuntimeException( Throwable cause ) {
		super( cause );
	}

}

==> refcodes-forwardsecrecy-3.2.5-sources.jar: org/refcodes/forwardsecrecy/UnexpectedForwardSecrecyRuntimeException.java <==
// /////////////////////////////////////////////////////////////////////////////
// REFCODES.ORG
// =============================================================================
// This code is copyright (c) by Siegfried Steiner, Munich, Germany, distributed
// on an "AS IS" BASIS WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, and licen-
// sed under the following (see "http://en.wikipedia.org/wiki/Multi-licensing")
// licenses:
// =============================================================================
// GNU General Public License, v3.0 ("http://www.gnu.org/licenses/gpl-3.0.html")
// together with the GPL linking exception applied; as being applied by the GNU
// Classpath ("http://www.gnu.org/software/classpath/license.html")
// =============================================================================
// Apache License, v2.0 ("http://www.apache.org/licenses/TEXT-2.0")
// =============================================================================
// Please contact the copyright holding author(s) of the software artifacts in
// question for licensing issues not being covered by the above listed licenses,
// also regarding commercial licensing models or regarding the compatibility
// with other open source licenses.
// /////////////////////////////////////////////////////////////////////////////

package org.refcodes.forwardsecrecy;

/**
 * This exception is the base runtime exception for the directory artifact.
 */
public class UnexpectedForwardSecrecyRuntimeException extends ForwardSecrecyRuntimeException {

	private static final long serialVersionUID = 1L;

	/**
	 * {@inheritDoc}
	 */
	public UnexpectedForwardSecrecyRuntimeException( String aMessage, String aErrorCode ) {
		super( aMessage, aErrorCode );
	}

	/**
	 * {@inheritDoc}
	 */
	public UnexpectedForwardSecrecyRuntimeException( String aMessage, Throwable aCause, String aErrorCode ) {
		super( aMessage, aCause, aErrorCode );
	}

	/**
	 * {@inheritDoc}
	 */
	public UnexpectedForwardSecrecyRuntimeException( String aMessage, Throwable aCause ) {
		super( aMessage, aCause );
	}

	/**
	 * {@inheritDoc}
	 */
	public UnexpectedForwardSecrecyRuntimeException( String aMessage ) {
		super( aMessage );
	}

	/**
	 * {@inheritDoc}
	 */
	public UnexpectedForwardSecrecyRuntimeException( Throwable aCause, String aErrorCode ) {
		super( aCause, aErrorCode );
	}

	/**
	 * {@inheritDoc}
	 */
	public UnexpectedForwardSecrecyRuntimeException( Throwable aCause ) {
		super( aCause );
	}

}
